@@ -1,9 +1,9 @@
 package ExpenseTracker::Controllers::Currency;
 {
-  $ExpenseTracker::Controllers::Currency::VERSION = '0.005';
+  $ExpenseTracker::Controllers::Currency::VERSION = '0.006';
 }
 {
-  $ExpenseTracker::Controllers::Currency::VERSION = '0.005';
+  $ExpenseTracker::Controllers::Currency::VERSION = '0.006';
 }
 use Mojo::Base 'ExpenseTracker::Controllers::Base';
 
@@ -18,4 +18,17 @@ sub new{
   
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+=pod
+ 
+=head1 NAME
+ExpenseTracker::Controllers::Currency - Controller responsible for the Currency resource
+
+
+=head1 VERSION
+
+version 0.006
+
+=cut
